@@ -5,19 +5,8 @@ import typing
 import typer
 
 import neosctl
-from neosctl import auth
-from neosctl import constant
-from neosctl import consume
-from neosctl import iam
-from neosctl import metadata
-from neosctl import product
-from neosctl import profile
-from neosctl import registry
-from neosctl import schema
-from neosctl import spark
-from neosctl import storage
-from neosctl.util import get_user_profile
-from neosctl.util import read_config_dotfile
+from neosctl import auth, constant, consume, iam, metadata, product, profile, registry, schema, spark, storage
+from neosctl.util import get_user_profile, read_config_dotfile
 
 
 def _generate_common_schema(
@@ -48,14 +37,17 @@ def _generate_common_schema(
 
 def version_callback(value: bool):
     if value:
-        typer.echo("neosctl {}".format(neosctl.__version__))
+        typer.echo(f"neosctl {neosctl.__version__}")
         raise typer.Exit()
 
 
 def callback(
     ctx: typer.Context,
-    version: typing.Optional[bool] = typer.Option(
-        None, "--version", callback=version_callback, help="Print version and exit.",
+    version: typing.Optional[bool] = typer.Option(  # noqa: ARG001
+        None,
+        "--version",
+        callback=version_callback,
+        help="Print version and exit.",
     ),
     gateway_api_url: str = typer.Option("", "--gateway-api-url", "--gurl", help="Gateway API URL"),
     registry_api_url: str = typer.Option("", "--registry-api-url", "--rurl", help="Registry API URL"),
@@ -63,7 +55,8 @@ def callback(
     storage_api_url: str = typer.Option("", "--storage-api-url", "--surl", help="Storage API URL"),
     profile: str = typer.Option(
         os.getenv("NEOSCTL_PROFILE", constant.DEFAULT_PROFILE),
-        "--profile", "-p",
+        "--profile",
+        "-p",
         help="Profile name",
     ),
 ):
