@@ -75,7 +75,7 @@ def create_from_json(
         return util.post(
             ctx,
             f"{product_url(ctx)}/{name}",
-            json=dpc.dict(exclude_none=True),
+            json=dpc.dict(exclude_none=True, by_alias=True),
         )
 
     fp = util.get_file_location(filepath)
