@@ -1,23 +1,21 @@
 import configparser
 import dataclasses
 from enum import Enum
-from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
+from typing import Any, Dict, List, Optional
 
+import pydantic
 from pydantic import BaseModel
 
 
 class FieldDataType(BaseModel):
     meta: Dict[str, Any]
-    type: str
+    type_: str = pydantic.Field(..., alias="type")
 
 
 class FieldDefinition(BaseModel):
     name: str
     description: Optional[str] = None
-    type: str
+    type_: str = pydantic.Field(..., alias="type")
     primary: bool
     optional: bool
     data_type: FieldDataType
@@ -113,7 +111,7 @@ class Common:
             url = self.gateway_api_url
         elif self.profile and self.profile.gateway_api_url:
             url = self.profile.gateway_api_url
-        return url
+        return url  # noqa: RET504
 
     def get_registry_api_url(self):
         url = None
@@ -121,7 +119,7 @@ class Common:
             url = self.registry_api_url
         if self.profile and self.profile.registry_api_url:
             url = self.profile.registry_api_url
-        return url
+        return url  # noqa: RET504
 
     def get_iam_api_url(self):
         url = None
@@ -129,7 +127,7 @@ class Common:
             url = self.iam_api_url
         if self.profile and self.profile.iam_api_url:
             url = self.profile.iam_api_url
-        return url
+        return url  # noqa: RET504
 
     def get_storage_api_url(self):
         url = None
@@ -137,4 +135,4 @@ class Common:
             url = self.storage_api_url
         if self.profile and self.profile.storage_api_url:
             url = self.profile.storage_api_url
-        return url
+        return url  # noqa: RET504
