@@ -8,7 +8,6 @@ from neosctl import util
 from neosctl.auth import ensure_login
 from neosctl.util import process_response
 
-
 app = typer.Typer()
 secret_app = typer.Typer()
 app.add_typer(secret_app, name="secret", help="Manage secrets for a spark job.")
@@ -33,6 +32,7 @@ def add_job(
     Assign and configure a spark job for a data product. This will result in a
     one off run of the spark job.
     """
+
     @ensure_login
     def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
         return util.post(
@@ -70,11 +70,12 @@ def generate_job(
     Generate a spark job from source/transformations configuration for a data product. This will result in a
     one off run of the spark job but no output.
     """
+
     @ensure_login
     def _request(ctx: typer.Context, data: typing.Dict) -> httpx.Response:
         return util.post(
             ctx,
-            "{spark_url}/generate".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/generate",
             json=data,
         )
 
@@ -93,13 +94,13 @@ def fetch_job_preview(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Fetch output of generate dry-run.
-    """
+    """Fetch output of generate dry-run."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            "{spark_url}/preview".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/preview",
         )
 
     r = _request(ctx)
@@ -112,14 +113,15 @@ def job_history(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Get history of spark applications.
-    """
+    """Get history of spark applications."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            "{spark_url}/history".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/history",
         )
+
     r = _request(ctx)
 
     process_response(r)
@@ -131,8 +133,8 @@ def run_history(
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     suffix: str = typer.Option(None, "--suffix", "-s"),
 ):
-    """Get history of spark application runs.
-    """
+    """Get history of spark application runs."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
@@ -142,6 +144,7 @@ def run_history(
                 suffix=suffix,
             ),
         )
+
     r = _request(ctx)
 
     process_response(r)
@@ -159,7 +162,6 @@ def job_status(
     Defaults to current application status, previous application status or a
     specific scheduled run can be requested.
     """
-
     params = {
         k: v
         for k, v in {
@@ -173,9 +175,10 @@ def job_status(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            "{spark_url}".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}",
             params=params,
         )
+
     r = _request(ctx)
 
     process_response(r)
@@ -210,9 +213,10 @@ def job_logs(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            "{spark_url}/log".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/log",
             params=params,
         )
+
     r = _request(ctx)
 
     process_response(r, render_logs)
@@ -228,6 +232,7 @@ def update_job(
 
     Update the assigned spark job file and/or the spark job configuration values.
     """
+
     @ensure_login
     def _request(
         ctx: typer.Context,
@@ -262,8 +267,8 @@ def remove_job(
         help="Force remove even if application is still running.",
     ),
 ):
-    """Remove assigned spark job.
-    """
+    """Remove assigned spark job."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
@@ -285,11 +290,12 @@ def trigger_job(
 
     Trigger an additional run of a spark job.
     """
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.post(
             ctx,
-            "{spark_url}/trigger".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/trigger",
         )
 
     r = _request(ctx)
@@ -304,7 +310,8 @@ def csv_job(
     quotechar: typing.Optional[str] = typer.Option(None, "--quote-char", "-q", help="csv quote char"),
     csv_write_mode: typing.Optional[str] = typer.Option(
         None,
-        "--write-mode", "-w",
+        "--write-mode",
+        "-w",
         help="csv write mode [overwrite|append]",
     ),
     job_filepath: str = typer.Option(..., "--job-filepath", "-f"),
@@ -313,6 +320,7 @@ def csv_job(
 
     Upload a csv file for processing into a data product.
     """
+
     @ensure_login
     def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
         params = {
@@ -327,7 +335,7 @@ def csv_job(
 
         return util.post(
             ctx,
-            "{spark_url}/csv".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/csv",
             params=params,
             files={"csv_file": f},
         )
@@ -350,11 +358,12 @@ def schedule_job(
 
     Schedule a spark job once it is configured correctly to run periodically.
     """
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.post(
             ctx,
-            "{spark_url}/scheduled".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/scheduled",
             json={
                 "cron_expression": schedule,
             },
@@ -374,11 +383,12 @@ def reschedule_job(
 
     Update existing scheduled spark job run schedule.
     """
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.put(
             ctx,
-            "{spark_url}/scheduled".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/scheduled",
             json={
                 "cron_expression": schedule,
             },
@@ -397,11 +407,12 @@ def unschedule_job(
 
     Remove existing scheduled spark job.
     """
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            "{spark_url}/scheduled".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/scheduled",
         )
 
     r = _request(ctx)
@@ -412,20 +423,25 @@ def unschedule_job(
 def stream_job(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
-    trigger_interval: str = typer.Option(..., "--trigger", "-t",
-                                         help='Trigger interval in spark format (e.g. "30 seconds")'),
+    trigger_interval: str = typer.Option(
+        ...,
+        "--trigger",
+        "-t",
+        help='Trigger interval in spark format (e.g. "30 seconds")',
+    ),
 ):
     """Run an infinite spark job.
 
     For streaming data product spark job will be created with given trigger interval.
     """
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         params = {"trigger_interval": trigger_interval}
 
         return util.post(
             ctx,
-            "{spark_url}/streaming".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/streaming",
             params=params,
         )
 
@@ -437,20 +453,25 @@ def stream_job(
 def restream_job(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
-    trigger_interval: str = typer.Option(..., "--trigger", "-t",
-                                         help='Trigger interval in spark format (e.g. "30 seconds")'),
+    trigger_interval: str = typer.Option(
+        ...,
+        "--trigger",
+        "-t",
+        help='Trigger interval in spark format (e.g. "30 seconds")',
+    ),
 ):
     """Update an infinite spark job.
 
     For streaming data product spark job will be removed and recreated with given trigger interval.
     """
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         params = {"trigger_interval": trigger_interval}
 
         return util.put(
             ctx,
-            "{spark_url}/streaming".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/streaming",
             params=params,
         )
 
@@ -467,12 +488,13 @@ def unstream_job(
 
     For streaming data product spark job will be removed and recreated with trigger interval "once".
     """
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
 
         return util.delete(
             ctx,
-            "{spark_url}/streaming".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            f"{spark_url(product_name, ctx.obj.gateway_api_url)}/streaming",
         )
 
     r = _request(ctx)
@@ -485,8 +507,8 @@ def add(
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     secrets: typing.List[str] = typer.Option(..., "--secret", "-s", help="Secret in the form key:value"),
 ):
-    """Add a set of secrets for a spark job.
-    """
+    """Add a set of secrets for a spark job."""
+
     @ensure_login
     def _request(ctx: typer.Context, payload: typing.Dict) -> httpx.Response:
         return util.post(
@@ -494,6 +516,7 @@ def add(
             secret_url(product_name, ctx.obj.gateway_api_url),
             json=payload,
         )
+
     payload = {"data": {}}
     for s in secrets:
         name, value = s.split(":")
@@ -515,6 +538,7 @@ def update(
     This will overwrite existing keys, and add new keys, any keys that already
     exist but aren't provided will remain.
     """
+
     @ensure_login
     def _request(ctx: typer.Context, payload: typing.Dict) -> httpx.Response:
         return util.patch(
@@ -522,6 +546,7 @@ def update(
             secret_url(product_name, ctx.obj.gateway_api_url),
             json=payload,
         )
+
     payload = {"data": {}}
     for s in secrets:
         name, value = s.split(":")
@@ -537,8 +562,8 @@ def remove(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Remove secret.
-    """
+    """Remove secret."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
@@ -557,13 +582,13 @@ def remove_key(
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     keys: typing.List[str] = typer.Option(..., "--key", "-k", help="Key name you wish to remove from secret"),
 ):
-    """Remove a set of keys from a secret.
-    """
+    """Remove a set of keys from a secret."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.delete(
             ctx,
-            "{secret_url}/key".format(secret_url=secret_url(product_name, ctx.obj.gateway_api_url)),
+            f"{secret_url(product_name, ctx.obj.gateway_api_url)}/key",
             json={"keys": keys},
         )
 
@@ -577,8 +602,8 @@ def get(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
-    """Get existing secret keys.
-    """
+    """Get existing secret keys."""
+
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
