@@ -7,7 +7,6 @@ from neosctl import util
 from neosctl.auth import ensure_login
 from neosctl.util import process_response
 
-
 app = typer.Typer()
 
 
@@ -25,19 +24,18 @@ def _load_statement(statement: typing.Optional[str], statement_filepath: typing.
     if statement_filepath:
         fp = util.get_file_location(statement_filepath)
 
-        statement = fp.read_text()
+        return fp.read_text()
 
     return statement
 
 
 def _load_params(params_filepath: typing.Optional[str]):
-    params = None
     if params_filepath:
         fp = util.get_file_location(params_filepath)
 
-        params = util.load_json_file(fp, "params")
+        return util.load_json_file(fp, "params")
 
-    return params
+    return None
 
 
 def _handle(
@@ -82,8 +80,7 @@ def execute(
         help="Filepath for statement params json file.",
     ),
 ):
-    """Execute a statement.
-    """
+    """Execute a statement."""
     _handle(ctx, "execute", statement, statement_filepath, params_filepath)
 
 
@@ -104,50 +101,47 @@ def executemany(
         help="Filepath for statement params json file.",
     ),
 ):
-    """Execute a statement with multiple input params.
-    """
+    """Execute a statement with multiple input params."""
     _handle(ctx, "executemany", statement, statement_filepath, params_filepath)
 
 
 @app.command()
 def fetch(
     ctx: typer.Context,
-    statement: str = typer.Option(None, "--statement", "-s", help="pSQL statement"),
-    statement_filepath: str = typer.Option(
+    statement: typing.Optional[str] = typer.Option(None, "--statement", "-s", help="pSQL statement"),
+    statement_filepath: typing.Optional[str] = typer.Option(
         None,
         "--statement-filepath",
         "-sf",
         help="Filepath for statement sql file.",
     ),
-    params_filepath: str = typer.Option(
+    params_filepath: typing.Optional[str] = typer.Option(
         None,
         "--params-filepath",
         "-pf",
         help="Filepath for statement params json file.",
     ),
 ):
-    """Fetch results of a statement.
-    """
+    """Fetch results of a statement."""
     _handle(ctx, "fetch", statement, statement_filepath, params_filepath)
 
 
 @app.command()
 def fetchrow(
     ctx: typer.Context,
-    statement: str = typer.Option(None, "--statement", "-s", help="pSQL statement"),
-    statement_filepath: str = typer.Option(
+    statement: typing.Optional[str] = typer.Option(None, "--statement", "-s", help="pSQL statement"),
+    statement_filepath: typing.Optional[str] = typer.Option(
         None,
         "--statement-filepath",
         "-sf",
         help="Filepath for statement sql file.",
     ),
-    params_filepath: str = typer.Option(
+    params_filepath: typing.Optional[str] = typer.Option(
         None,
         "--params-filepath",
         "-pf",
         help="Filepath for statement params json file.",
     ),
 ):
-    """Fetch first result of a statement.
-    """
+    """Fetch first result of a statement."""
     _handle(ctx, "fetchrow", statement, statement_filepath, params_filepath)
